@@ -19,6 +19,7 @@ from ioflo.aid.sixing import *
 from ioflo.aid.consoling import getConsole
 from ioflo.aio import wiring
 from ioflo.aio.udp import udping
+from ioflo.aio import aioing
 
 console = getConsole()
 
@@ -121,12 +122,25 @@ class BasicTestCase(unittest.TestCase):
         Test Class SocketUdpNb
         """
         console.terse("{0}\n".format(self.testBroadcast.__doc__))
+
+
+        try:  # only run if netifaces installed
+            from ioflo.aio.aioing import getDefaultHost,  getDefaultBroadcast
+        except ImportError:
+            return
+
+
         console.reinit(verbosity=console.Wordage.profuse)
 
-        unicast = socket.gethostbyname(socket.gethostname())
-        parts = unicast.split('.')
-        parts[3] = '255'
-        broadcast = ".".join(parts)  # make broadcast send address
+
+        #unicast = socket.gethostbyname(socket.gethostname())
+        unicast = getDefaultHost()
+
+        #parts = unicast.split('.')
+        #parts[3] = '255'
+        #broadcast = ".".join(parts)  # make broadcast send address
+
+        broadcast = getDefaultBroadcast()
         bha = (broadcast, 6102)
 
         alpha = udping.SocketUdpNb(host=unicast,
